==> p_pattern-2025.1.tar.gz: p_pattern-2025.1/package/p_pattern/catalog/instance/c_extension.py <==
"""
Copyright CNRS (https://www.cnrs.fr/index.php/en)
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2025
SEE COPYRIGHT NOTICE BELOW
"""

import typing as h
from ctypes import c_void_p, cdll
from pathlib import Path as path_t
from sys import platform as OS_TYPE

c_types_t = type(c_void_p)

_EXTENSION_FOLDER = "c_extension"
_EXTENSION_EXTENSION = "so"


def RegionImplementationInC(
    from_module: str, arguments: tuple[c_types_t, ...], /
) -> h.Any:
    """"""
    path = path_t(from_module)
    extension = (
        path.parent
        / _EXTENSION_FOLDER
        / f"{path.stem}-{OS_TYPE}.{_EXTENSION_EXTENSION}"
    )
    if extension.is_file():
        try:
            library = cdll.LoadLibrary(str(extension))
        except OSError:
            return None

        output = library.Region
        output.argtypes = arguments
        output.restype = None

        return output

    return None


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.
"""

==> p_pattern-2025.2.tar.gz: p_pattern-2025.2/package/p_pattern/catalog/instance/c_extension.py <==
"""
Copyright CNRS (https://www.cnrs.fr/index.php/en)
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2025
SEE COPYRIGHT NOTICE BELOW
"""

import platform as pltf
import typing as h
from ctypes import c_void_p, cdll
from pathlib import Path as path_t
from sys import platform as OS_TYPE

c_types_t = type(c_void_p)

_EXTENSION_FOLDER = "c_extension"
_EXTENSION_EXTENSION = "so"


def RegionImplementationInC(
    from_module: str, arguments: tuple[c_types_t, ...], /
) -> h.Any:
    """"""
    path = path_t(from_module)
    # Keep in sync with make.sh.
    extension = (
        path.parent
        / _EXTENSION_FOLDER
        / f"{path.stem}-{OS_TYPE}-{pltf.machine()}.{_EXTENSION_EXTENSION}"
    )
    if extension.is_file():
        try:
            library = cdll.LoadLibrary(str(extension))
        except OSError:
            return None

        output = library.Region
        output.argtypes = arguments
        output.restype = None

        return output

    return None


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.
"""
